<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ca_ES">
<context>
    <name>ConfigureHID</name>
    <message>
        <location filename="configurehid.ui" line="33"/>
        <source>Configure HID Plugin</source>
        <translation>Configurar plugin HID</translation>
    </message>
    <message>
        <location filename="configurehid.ui" line="52"/>
        <source>Input Line</source>
        <translation>Línia d&apos;Entrada</translation>
    </message>
    <message>
        <location filename="configurehid.ui" line="57"/>
        <source>Name</source>
        <translation>Nom</translation>
    </message>
    <message>
        <location filename="configurehid.ui" line="62"/>
        <source>Merger Mode</source>
        <translation>Mode Fusió</translation>
    </message>
    <message>
        <location filename="configurehid.ui" line="70"/>
        <source>Refresh</source>
        <translation>Actualitzar</translation>
    </message>
</context>
<context>
    <name>HIDDMXDevice</name>
    <message>
        <location filename="hiddmxdevice.cpp" line="62"/>
        <source>HID DMX Interface Error</source>
        <translation>HID DMX error d&apos;interfície</translation>
    </message>
    <message>
        <location filename="hiddmxdevice.cpp" line="63"/>
        <source>Unable to open %1. Make sure the udev rule is installed.</source>
        <translation>No es pot obrir %1. Assegurar-vos que la regla de udev està instal·lada.</translation>
    </message>
</context>
<context>
    <name>HIDJsDevice</name>
    <message>
        <location filename="hidjsdevice.cpp" line="116"/>
        <source>Axes: %1</source>
        <translation>Eixos: %1</translation>
    </message>
    <message>
        <location filename="hidjsdevice.cpp" line="118"/>
        <source>Buttons: %1</source>
        <translation>Botons: %1</translation>
    </message>
</context>
<context>
    <name>HIDPlugin</name>
    <message>
        <location filename="hidplugin.cpp" line="125"/>
        <source>This plugin provides support for HID-based joysticks, gamepads and some USB DMX adapters.</source>
        <translation>Aquest plugin proveeix support HID per joysticks, gamepads i alguns adaptadors USB DMX.</translation>
    </message>
</context>
</TS>
